#region Copyright Syncfusion Inc. 2001 - 2015
// Copyright Syncfusion Inc. 2001 - 2015. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
using System.Collections.ObjectModel;
using System;


#endregion
using Syncfusion.SfChart.XForms;
using Xamarin.Forms;

namespace SimpleSample
{
    public class Column : ContentPage
    {
		SfChart chart;
        public Column()
        {
            Title = "Column Series";
			Content = new StackLayout()
			{
			    Padding  = new Thickness(0,15,0,0),
				Children = { GetChart() }
			};
        }

		public SfChart GetChart()
        {
            chart = new SfChart
            {
               PrimaryAxis = new CategoryAxis 
				{
					LabelPlacement = LabelPlacement.BetweenTicks,
					LabelsIntersectAction = AxisLabelsIntersectAction.MultipleRows,
					LabelStyle = new ChartAxisLabelStyle
					{
						LabelsPosition = AxisElementPosition.Outside,
					},
					ShowMajorGridLines = true,
					MajorGridLineStyle = new ChartLineStyle
					{
						StrokeWidth = Device.OnPlatform(0.25,1,1)
					},
					Interval = 1,
                    ZoomFactor = 0.35,
					// when zooming auto interval is calculated, to avoid this set EnableAutoIntervalOnZooming as false
					EnableAutoIntervalOnZooming = false
				},

               SecondaryAxis = new NumericalAxis
				{
					ShowMajorGridLines =false,
					LabelStyle = new ChartAxisLabelStyle
					{
						LabelsPosition = AxisElementPosition.Outside,
					},
					Title = new ChartAxisTitle
					{
						Text = "Steps"
					}
				},

				Legend = new ChartLegend
				{
					Orientation = ChartOrientation.Horizontal,
					DockPosition = LegendPlacement.Top,
					IsIconVisible = true,
					IsVisible = true,
					ToggleSeriesVisibility = true,
				},
            };
			chart.VerticalOptions = LayoutOptions.FillAndExpand;
            chart.Series.Add(new ColumnSeries
            {
				Label = "Steps",
				ItemsSource = GetSelectionData(),
            });

            ChartZoomPanBehavior zoomBehaviour = new ChartZoomPanBehavior
            {
                    EnablePanning = true,
                    EnableZooming = false,
                    EnableDoubleTap = false,
                    EnableSelectionZooming = false,
            };
            chart.ChartBehaviors.Add(zoomBehaviour);
            return chart;
        }

		public ObservableCollection<ChartDataPoint> GetSelectionData()
		{
            ObservableCollection<ChartDataPoint> data = new ObservableCollection<ChartDataPoint>();

            DateTime d = new DateTime(2010, 01, 01);
            const int buckets = 36;
            const double median = 40.0;
            const double range = 50.0;
            Random rng = new Random();
            for (int i = 0; i < buckets; ++i)
            {
                string bucketLabel = GetLabel(d);
                double y = median + (rng.NextDouble() - 0.5) * range;
                ChartDataPoint p = new ChartDataPoint(bucketLabel, y);
                data.Add(p);
                d = d.AddMonths(1);
            }
            return data;
		}

        private string GetLabel(DateTime date)
        {
            string label = date.ToString("MMM\n dd");
            return label;
        }
    }
}